instrumenttools.Cello
=====================

.. abjad-lineage:: abjad.tools.instrumenttools.Cello.Cello.Cello

.. autoclass:: abjad.tools.instrumenttools.Cello.Cello.Cello
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.Cello.Cello.Cello.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Cello.Cello.Cello.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Cello.Cello.Cello.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Cello.Cello.Cello.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Cello.Cello.Cello.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Cello.Cello.Cello.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Cello.Cello.Cello.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Cello.Cello.Cello.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Cello.Cello.Cello.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Cello.Cello.Cello.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Cello.Cello.Cello.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Cello.Cello.Cello.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.Cello.Cello.Cello.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Cello.Cello.Cello.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Cello.Cello.Cello.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Cello.Cello.Cello.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Cello.Cello.Cello.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Cello.Cello.Cello.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Cello.Cello.Cello.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Cello.Cello.Cello.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.Cello.Cello.Cello.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Cello.Cello.Cello.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Cello.Cello.Cello.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Cello.Cello.Cello.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.Cello.Cello.Cello.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Cello.Cello.Cello.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Cello.Cello.Cello.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Cello.Cello.Cello.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Cello.Cello.Cello.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Cello.Cello.Cello.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Cello.Cello.Cello.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Cello.Cello.Cello.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Cello.Cello.Cello.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Cello.Cello.Cello.__repr__
   :noindex:
